pub fn run_tern_test(case: &TernTestCase) -> TernTestResultExpand description
Run a single test case through the complete ternlang pipeline and return a result indicating pass/fail with a diagnostic message.
pub fn run_tern_test(case: &TernTestCase) -> TernTestResultRun a single test case through the complete ternlang pipeline and return a result indicating pass/fail with a diagnostic message.